@@ -7,10 +7,7 @@ Usage::
     import boto3
     from mypy_boto3_codestar_notifications import CodeStarNotificationsClient
 
-    session = boto3.Session()
-
     client: CodeStarNotificationsClient = boto3.client("codestar-notifications")
-    session_client: CodeStarNotificationsClient = session.client("codestar-notifications")
     ```
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
