@@ -7,7 +7,7 @@ Usage::
     import boto3
 
     from mypy_boto3_codestar_notifications import CodeStarNotificationsClient
-    from mypy_boto3_codestar_notifications import (
+    from mypy_boto3_codestar_notifications.paginator import (
         ListEventTypesPaginator,
         ListNotificationRulesPaginator,
         ListTargetsPaginator,
